# nsi25Perlin

nsi25Perlin is a small module that implements Perlin's noise.
nsi25Perlin has been designed for the [Trophées NSI 2025](https://trophees-nsi.fr).

## Warning

This package is not maintained and is not intended to be used.